/*
 * Copyright 2013 eXo Platform SAS
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package juzu.plugin.less;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * This annotation trigger declares a less stylesheet. It triggers the compilation of a less stylesheet when it is
 * processed. by the compiler.
 *
 * @author <a href="mailto:julien.viet@exoplatform.com">Julien Viet</a>
 */
@Retention(RetentionPolicy.SOURCE)
@Target(ElementType.PACKAGE)
public @interface Less {

  /**
   * The path of the less stylesheet to compile, relative to the <code>assets</code> application package.
   *
   * @return the stylesheet paths
   */
  String[] value();

  /**
   * Configure the minification of the stylesheet when they are processed. The stylesheets are not minified by
   * default.
   *
   * @return true if the stylesheets should be minidfied
   */
  boolean minify() default false;

}
